contexttools.detach_time_signature_marks_attached_to_component
==============================================================

.. autofunction:: abjad.tools.contexttools.detach_time_signature_marks_attached_to_component.detach_time_signature_marks_attached_to_component
